# Speak2Mary

A Python wrapper for the MaryTTS Test-To-Speak system. It maps the http endpoints to python methods.

Its mainly used for generating sound from an running MaryTTS server.

## Requirements

* Python 3 or higher

## Install

The module is available via `pip install speak2mary`.

## Examples

For example how to use the library take a look at the [tests](https://github.com/Poeschl/speak2mary/blob/master/tests/test_marytts.py).
